@@ -461,68 +461,87 @@ MHD_socket_noninheritable_ (MHD_socket sock)
 }
 
 
+/**
+ * Change socket buffering mode to default.
+ *
+ * @param sock socket to manipulate
+ * @return non-zero if succeeded, zero otherwise
+ */
+int
+MHD_socket_buffering_reset_ (MHD_socket sock)
+{
+  int res = !0;
+#if defined(TCP_NODELAY) || defined(MHD_TCP_CORK_NOPUSH)
+  const MHD_SCKT_OPT_BOOL_ off_val = 0;
+#if defined(MHD_TCP_CORK_NOPUSH)
+  /* Disable extra buffering */
+  res = (0 == setsockopt (sock,
+                          IPPROTO_TCP,
+                          MHD_TCP_CORK_NOPUSH,
+                          (const void *) &off_val,
+                          sizeof (off_val))) && res;
+#endif /* MHD_TCP_CORK_NOPUSH */
+#if defined(TCP_NODELAY)
+  /* Enable Nagle's algorithm for normal buffering */
+  res = (0 == setsockopt (sock,
+                          IPPROTO_TCP,
+                          TCP_NODELAY,
+                          (const void *) &off_val,
+                          sizeof (off_val))) && res;
+#endif /* TCP_NODELAY */
+#else  /* !TCP_NODELAY && !MHD_TCP_CORK_NOPUSH */
+  (void) sock;
+#endif /* !TCP_NODELAY && !MHD_TCP_CORK_NOPUSH */
+  return res;
+}
+
+
 /**
  * Create a listen socket, with noninheritable flag if possible.
  *
- * @param use_ipv6 if set to non-zero IPv6 is used
+ * @param pf protocol family to use
  * @return created socket or MHD_INVALID_SOCKET in case of errors
  */
 MHD_socket
-MHD_socket_create_listen_ (int use_ipv6)
+MHD_socket_create_listen_ (int pf)
 {
-  int domain;
   MHD_socket fd;
   int cloexec_set;
-#if defined(OSX) && defined(SOL_SOCKET) && defined(SO_NOSIGPIPE)
-  static const int on_val = 1;
-#endif
-
-#ifdef HAVE_INET6
-  domain = (use_ipv6) ? PF_INET6 : PF_INET;
-#else  /* ! HAVE_INET6 */
-  if (use_ipv6)
-    return MHD_INVALID_SOCKET;
-  domain = PF_INET;
-#endif /* ! HAVE_INET6 */
 
 #if defined(MHD_POSIX_SOCKETS) && defined(SOCK_CLOEXEC)
-  fd = socket (domain,
+  fd = socket (pf,
                SOCK_STREAM | SOCK_CLOEXEC,
                0);
   cloexec_set = !0;
 #elif defined(MHD_WINSOCK_SOCKETS) && defined (WSA_FLAG_NO_HANDLE_INHERIT)
-  fd = WSASocketW (domain,
+  fd = WSASocketW (pf,
                    SOCK_STREAM,
                    0,
                    NULL,
                    0,
-                   WSA_FLAG_NO_HANDLE_INHERIT);
+                   WSA_FLAG_OVERLAPPED | WSA_FLAG_NO_HANDLE_INHERIT);
   cloexec_set = !0;
 #else  /* !SOCK_CLOEXEC */
   fd = MHD_INVALID_SOCKET;
 #endif /* !SOCK_CLOEXEC */
   if (MHD_INVALID_SOCKET == fd)
     {
-      fd = socket (domain,
+      fd = socket (pf,
                    SOCK_STREAM,
                    0);
       cloexec_set = 0;
     }
   if (MHD_INVALID_SOCKET == fd)
     return MHD_INVALID_SOCKET;
-#if defined(OSX) && defined(SOL_SOCKET) && defined(SO_NOSIGPIPE)
-  if(0 != setsockopt(fd,
-                     SOL_SOCKET,
-                     SO_NOSIGPIPE,
-                     &on_val,
-                     sizeof (on_val)))
+#ifdef MHD_socket_nosignal_
+  if(! MHD_socket_nosignal_(fd))
     {
-      int err = MHD_socket_get_error_ ();
-      MHD_socket_close_ (fd);
+      const int err = MHD_socket_get_error_ ();
+      (void) MHD_socket_close_ (fd);
       MHD_socket_fset_error_ (err);
       return MHD_INVALID_SOCKET;
     }
-#endif
+#endif /* MHD_socket_nosignal_ */
   if (! cloexec_set)
     (void) MHD_socket_noninheritable_ (fd);
 
